from tirppa import Tirppa
from pillar import Pillar

import pygame as pg

from random import randint, random

MAX_SECONDS_BETWEEN_PILLARS = 5
MIN_SECONDS_BETWEEN_PILLARS = 1.5


class Game:
    def __init__(self) -> None:
        pg.init()
        size = (800, 600)
        self.screen = pg.display.set_mode(size)
        self.prep_game_over_text()

        self.tirppa = Tirppa(*size)
        self.pillars = []

    def loop(self):
        while self.running:
            self.events()
            self.logic()
            self.draw()

    def events(self):
        for event in pg.event.get():
            if event.type == pg.QUIT:
                self.running = False
                return
            if event.type == pg.KEYDOWN:
                if event.key == pg.K_SPACE:
                    self.tirppa.flap()

    def logic(self):
        self.tirppa.move()
        for pillar in self.pillars:
            if not self.tirppa.dead and pillar.rect.colliderect(self.tirppa.rect):
                self.tirppa.die()
            pillar.move()

        if self.next_spawn_time <= 0:
            self.spawn_pillars()
            self.next_spawn_time = max(
                MIN_SECONDS_BETWEEN_PILLARS,
                random()*MAX_SECONDS_BETWEEN_PILLARS,
            ) * 1000

        self.next_spawn_time -= self.clock.tick(60)

    def draw(self):
        self.screen.fill(pg.color.Color(33, 33, 33))
        self.tirppa.blit(self.screen)
        for pillar in self.pillars:
            pillar.blit(self.screen)
        if self.tirppa.dead:
            self.show_game_over_text()
        pg.display.flip()

    def start(self):
        self.clock = pg.time.Clock()
        self.next_spawn_time = 0
        self.running = True
        self.loop()

    def spawn_pillars(self):
        height = randint(100, 500)
        gap = randint(150, 250)
        left = 1000

        for pillar in [Pillar(True, height-gap/2, left), Pillar(False, height+gap/2, left)]:
            self.pillars.append(pillar)

    def prep_game_over_text(self):
        font_path = pg.font.get_default_font()
        font = pg.font.Font(font_path, 24)

        text = font.render("Game over", True, (255, 255, 255))

        # Center the text
        text_rect = text.get_rect()
        text_rect.y = 10
        text_rect.x = self.screen.get_rect().w/2-text_rect.w/2

        self.game_over_text = text
        self.game_over_text_rect = text_rect

    def show_game_over_text(self):
        self.screen.blit(self.game_over_text, self.game_over_text_rect)
