import pygame as pg

from drawable import Drawable


def get_sprite():
    # Lataa kuva, convert_alpha hoitaa läpinäkyvät pikselit
    sprite = pg.image.load('flappy_bird.png').convert_alpha()

    # Rajaa kuva näkyviin pikseleihin
    sprite = sprite.subsurface(sprite.get_bounding_rect())

    # Kutista kuvaa
    rect = sprite.get_rect()
    aspect_ratio = rect.h / rect.w
    new_width = 100
    sprite = pg.transform.scale(sprite, (new_width, new_width*aspect_ratio))

    return sprite


# Hattuvakioita
GRAVITY = 0.2
FLAP_STRENGTH = 4
TERMINAL_VELOCITY = 8


class Tirppa(Drawable):
    def __init__(self, max_width, max_height) -> None:
        super().__init__(get_sprite())
        self.velocity = 0
        self.dead = False
        self.play_area = pg.Rect(0, 0, max_width, max_height)

    def move(self):
        self.velocity += GRAVITY
        self.velocity = min(self.velocity, TERMINAL_VELOCITY)
        self.rect.move_ip((0, self.velocity))

        self.rect.clamp_ip(self.play_area)

    def flap(self):
        if not self.dead:
            self.velocity = min(self.velocity, 0) - FLAP_STRENGTH

    def die(self):
        self.velocity = -10
        self.dead = True
